.. module:: brownie.itools

Iteration Tools
===============

Implements :mod:`itertools` functions for earlier versions of Python.

.. autoclass:: chain
   :members:

.. autofunction:: izip_longest

.. autofunction:: permutations

.. autofunction:: product

.. autofunction:: starmap

.. autofunction:: combinations_with_replacement

.. autofunction:: compress

.. autofunction:: count

.. autofunction:: grouped

.. autofunction:: unique
